@@ -6,7 +6,6 @@ use Pcore::Lib::File::Tree;
 has dist => ();    # InstanceOf ['Pcore::Dist']
 
 has wiki   => ( is => 'lazy', init_arg => undef );    # Maybe [ InstanceOf ['Pcore::Dist::Build::Wiki'] ]
-has issues => ( is => 'lazy', init_arg => undef );    # Maybe [ InstanceOf ['Pcore::Dist::Build::Issues'] ]
 has docker => ( is => 'lazy', init_arg => undef );    # Maybe [ InstanceOf ['Pcore::Dist::Build::Docker'] ]
 
 sub _build_wiki ($self) {
@@ -15,12 +14,6 @@ sub _build_wiki ($self) {
     return Pcore::Dist::Build::Wiki->new( { dist => $self->{dist} } );
 }
 
-sub _build_issues ($self) {
-    require Pcore::Dist::Build::Issues;
-
-    return Pcore::Dist::Build::Issues->new( { dist => $self->{dist} } );
-}
-
 sub _build_docker ($self) {
     require Pcore::Dist::Build::Docker;
 
@@ -135,7 +128,7 @@ sub tgz ($self) {
 
     my $tgz = Archive::Tar->new;
 
-    my $base_dir = $self->{dist}->name . q[-] . $self->{dist}->version;
+    my $base_dir = $self->{dist}->name . q[-] . $self->{dist}->id->{release};
 
     for my $path ( $temp->read_dir( max_depth => 0, is_dir => 0 )->@* ) {
         my $mode;
